@@ -20,6 +20,9 @@ import tempfile
 import datetime
 import operator
 from concurrent.futures import ThreadPoolExecutor as Executor
+
+from gi.repository import GObject
+
 from kb4it.core.env import LPATH, GPATH, APP, ADOCPROPS, MAX_WORKERS, EOHMARK
 from kb4it.core.service import Service
 from kb4it.core.util import get_human_datetime
@@ -604,7 +607,6 @@ class KB4ITApp(Service):
         shutil.rmtree(self.runtime['dir']['tmp'])
         self.log.info("Temporary directory %s deleted successfully", self.runtime['dir']['tmp'])
 
-
     def run(self):
         """Start script execution following this flow.
 
@@ -619,6 +621,7 @@ class KB4ITApp(Service):
         """
         self.log.info("KB4IT - Knowledge Base for IT")
 
+        self.running = True
         self.stage_01_check_environment()
         self.srvthm.generate_sources()
         self.stage_02_get_source_documents()
@@ -629,8 +632,10 @@ class KB4ITApp(Service):
         self.stage_07_clean_target()
         self.stage_08_refresh_target()
         self.stage_09_remove_temporary_dir()
-
         self.log.info("KB4IT - Execution finished")
         self.log.info("Browse your documentation repository:")
         self.log.info("sensible-browser %s/index.html", os.path.abspath(self.runtime['dir']['target']))
+        self.running = False
 
+    def is_running(self):
+        return self.running
